# frozen_string_literal: true

describe WPScan::Vulnerability do
  subject(:vuln)   { described_class.new(title, references: references) }
  let(:title)      { 'Test Vuln' }
  let(:references) { {} }

  it_behaves_like WPScan::References

  describe '#load_from_json' do
    # Handled in spec/app/models/wp_version_spec#vulnerabilities
  end
end
